# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ocrProfileNameDialog.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ocrNameDialog(object):
    def setupUi(self, ocrNameDialog):
        ocrNameDialog.setObjectName("ocrNameDialog")
        ocrNameDialog.resize(859, 203)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ocrNameDialog.sizePolicy().hasHeightForWidth())
        ocrNameDialog.setSizePolicy(sizePolicy)
        ocrNameDialog.setMinimumSize(QtCore.QSize(0, 0))
        ocrNameDialog.setMaximumSize(QtCore.QSize(16777215, 300))
        self.gridLayout = QtWidgets.QGridLayout(ocrNameDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(ocrNameDialog)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.profileNameEdit = QtWidgets.QLineEdit(ocrNameDialog)
        self.profileNameEdit.setObjectName("profileNameEdit")
        self.gridLayout.addWidget(self.profileNameEdit, 1, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(ocrNameDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 2, 0, 1, 1)

        self.retranslateUi(ocrNameDialog)
        self.buttonBox.accepted.connect(ocrNameDialog.accept)
        self.buttonBox.rejected.connect(ocrNameDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(ocrNameDialog)

    def retranslateUi(self, ocrNameDialog):
        _translate = QtCore.QCoreApplication.translate
        ocrNameDialog.setWindowTitle(_translate("ocrNameDialog", "OCR Profile Name "))
        self.label.setText(_translate("ocrNameDialog", "<html><head/><body><p>It is important to clearly identify a saved OCR profile. A minimum is:</p><p>1) Initials of user (because it is possible to share your profiles with other users) +</p><p>2) Equipment chain: camera(PAL/NTSC) VTI frame-grabber</p><p>For example: RLA Watec-910-NTSC IOTA-VTI3 svid2usb2</p></body></html>"))





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'starPositionDialog.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(580, 400)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(580, 400))
        Dialog.setMaximumSize(QtCore.QSize(580, 400))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(460, 80, 81, 71))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(120, 60, 60, 16))
        self.label.setObjectName("label")
        self.label_5 = QtWidgets.QLabel(Dialog)
        self.label_5.setGeometry(QtCore.QRect(310, 60, 60, 16))
        self.label_5.setObjectName("label_5")
        self.layoutWidget = QtWidgets.QWidget(Dialog)
        self.layoutWidget.setGeometry(QtCore.QRect(262, 81, 145, 91))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.DecDegrees = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecDegrees.sizePolicy().hasHeightForWidth())
        self.DecDegrees.setSizePolicy(sizePolicy)
        self.DecDegrees.setMinimumSize(QtCore.QSize(80, 0))
        self.DecDegrees.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecDegrees.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecDegrees.setObjectName("DecDegrees")
        self.horizontalLayout_4.addWidget(self.DecDegrees)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_4.addWidget(self.label_6)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.DecMinutes = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecMinutes.sizePolicy().hasHeightForWidth())
        self.DecMinutes.setSizePolicy(sizePolicy)
        self.DecMinutes.setMinimumSize(QtCore.QSize(80, 0))
        self.DecMinutes.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecMinutes.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecMinutes.setObjectName("DecMinutes")
        self.horizontalLayout_5.addWidget(self.DecMinutes)
        self.label_7 = QtWidgets.QLabel(self.layoutWidget)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_5.addWidget(self.label_7)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.DecSeconds = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecSeconds.sizePolicy().hasHeightForWidth())
        self.DecSeconds.setSizePolicy(sizePolicy)
        self.DecSeconds.setMinimumSize(QtCore.QSize(80, 0))
        self.DecSeconds.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecSeconds.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecSeconds.setObjectName("DecSeconds")
        self.horizontalLayout_6.addWidget(self.DecSeconds)
        self.label_8 = QtWidgets.QLabel(self.layoutWidget)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_6.addWidget(self.label_8)
        self.verticalLayout_2.addLayout(self.horizontalLayout_6)
        self.label_9 = QtWidgets.QLabel(Dialog)
        self.label_9.setGeometry(QtCore.QRect(90, 20, 341, 16))
        self.label_9.setObjectName("label_9")
        self.label_11 = QtWidgets.QLabel(Dialog)
        self.label_11.setGeometry(QtCore.QRect(30, 200, 511, 71))
        self.label_11.setObjectName("label_11")
        self.layoutWidget1 = QtWidgets.QWidget(Dialog)
        self.layoutWidget1.setGeometry(QtCore.QRect(61, 81, 145, 91))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.RaHours = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaHours.sizePolicy().hasHeightForWidth())
        self.RaHours.setSizePolicy(sizePolicy)
        self.RaHours.setMinimumSize(QtCore.QSize(80, 0))
        self.RaHours.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaHours.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaHours.setObjectName("RaHours")
        self.horizontalLayout.addWidget(self.RaHours)
        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.RaMinutes = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaMinutes.sizePolicy().hasHeightForWidth())
        self.RaMinutes.setSizePolicy(sizePolicy)
        self.RaMinutes.setMinimumSize(QtCore.QSize(80, 0))
        self.RaMinutes.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaMinutes.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaMinutes.setObjectName("RaMinutes")
        self.horizontalLayout_2.addWidget(self.RaMinutes)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_2.addWidget(self.label_3)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.RaSeconds = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaSeconds.sizePolicy().hasHeightForWidth())
        self.RaSeconds.setSizePolicy(sizePolicy)
        self.RaSeconds.setMinimumSize(QtCore.QSize(80, 0))
        self.RaSeconds.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaSeconds.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaSeconds.setObjectName("RaSeconds")
        self.horizontalLayout_3.addWidget(self.RaSeconds)
        self.label_4 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.layoutWidget2 = QtWidgets.QWidget(Dialog)
        self.layoutWidget2.setGeometry(QtCore.QRect(100, 340, 391, 23))
        self.layoutWidget2.setObjectName("layoutWidget2")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.layoutWidget2)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_10 = QtWidgets.QLabel(self.layoutWidget2)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        self.apiKeyEdit = QtWidgets.QLineEdit(self.layoutWidget2)
        self.apiKeyEdit.setObjectName("apiKeyEdit")
        self.horizontalLayout_7.addWidget(self.apiKeyEdit)
        self.layoutWidget3 = QtWidgets.QWidget(Dialog)
        self.layoutWidget3.setGeometry(QtCore.QRect(30, 280, 471, 23))
        self.layoutWidget3.setObjectName("layoutWidget3")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.layoutWidget3)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_12 = QtWidgets.QLabel(self.layoutWidget3)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_8.addWidget(self.label_12)
        self.singleLineEdit = QtWidgets.QLineEdit(self.layoutWidget3)
        self.singleLineEdit.setObjectName("singleLineEdit")
        self.horizontalLayout_8.addWidget(self.singleLineEdit)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.RaHours, self.RaMinutes)
        Dialog.setTabOrder(self.RaMinutes, self.RaSeconds)
        Dialog.setTabOrder(self.RaSeconds, self.DecDegrees)
        Dialog.setTabOrder(self.DecDegrees, self.DecMinutes)
        Dialog.setTabOrder(self.DecMinutes, self.DecSeconds)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "RA"))
        self.label_5.setText(_translate("Dialog", "Dec"))
        self.label_6.setText(_translate("Dialog", "degrees"))
        self.label_7.setText(_translate("Dialog", "minutes"))
        self.label_8.setText(_translate("Dialog", "seconds"))
        self.label_9.setText(_translate("Dialog", "<html><head/><body><p>Set/Confirm ICRS J2000 coordinates for occulted star</p></body></html>"))
        self.label_11.setText(_translate("Dialog", "<html><head/><body><p>Alternative single line entry (eases copy and paste from VizieR query):</p><p>Use form <span style=\" font-weight:600; color:#fc0107;\">6h32m45.66s -23d31m29.11s</span> (<span style=\" color:#000000;\">the +/- sign for Dec </span><span style=\" font-weight:600; font-style:italic; text-decoration: underline; color:#fc0107;\">MUST</span><span style=\" color:#000000;\">  be present !!</span>)</p></body></html>"))
        self.label_2.setText(_translate("Dialog", "hours"))
        self.label_3.setText(_translate("Dialog", "minutes"))
        self.label_4.setText(_translate("Dialog", "seconds"))
        self.label_10.setText(_translate("Dialog", "nova.astrometry.net API key:"))
        self.label_12.setText(_translate("Dialog", "Star coordinates (hmsdms)"))






class Temp:

    def getF(self):
        return self._temperatureF

    def setF(self, temp_fahrenheit):
        self._temperatureF = temp_fahrenheit
        self._temperatureC = (5/9) * (self._temperatureF - 32.0)

    def getC(self):
        return self._temperatureC

    def setC(self, temp_centigrade):
        self._temperatureC = temp_centigrade
        self._temperatureF = (9/5) * self._temperatureC + 32


    def __init__(self):
        self._temperatureF = None
        self._temperatureC = None

    temperatureF = property(getF, setF)
    temperatureC = property(getC, setC)

bob = Temp()
print(bob.temperatureF)
bob.temperatureF = 212
print(f'{bob.temperatureC} degrees Centigrade')
print(f'{bob.temperatureF} degrees Fahrenheit')





import pyqtgraph as pg
from pyqtgraph.Qt import QtCore, QtGui
from PyQt5.QtCore import pyqtSignal
from PyQt5.QtWidgets import QDialog
from pymovie import apertureNameDialog


class AppNameDialog(QDialog, apertureNameDialog.Ui_Dialog):
    def __init__(self):
        super(AppNameDialog, self).__init__()
        self.setupUi(self)

class HorizontalLine(pg.GraphicsObject):
    def __init__(self, rowNumber, height, width, colorStr):  # Intialize aperture specified by a bounding box
        self.pen = pg.mkPen(colorStr)
        self.y0 = rowNumber
        self.x0 = 0
        self.x1 = width
        self.h = height
        self.w = width

        # note that the use of super() is often avoided because Qt does not
        # allow to inherit from multiple QObject subclasses.
        pg.GraphicsObject.__init__(self)

    # All graphics items must have paint() defined.
    def paint(self, p, *args):
        _ = args  # Just to satisfy PyCharm code inspector (need to use args in some manner)
        p.setPen(self.pen)
        p.drawLine(self.x0, self.y0, self.x1, self.y0)

    # All graphics items must have boundingRect() defined.
    def boundingRect(self):
        return QtCore.QRectF(0, 0, self.w, self.h)

    def setRow(self, row):
        self.y0 = row
        self.update()

class MeasurementAperture(pg.GraphicsObject):
    """
    This class draws a rectangular area. Right-clicking inside the area will
    raise a custom context menu which also could include the context menus of
    its parents.
    """

    # Define Qt Signal that we will use to send information from this object to the UI
    # We are going sent the aperture object itself to the connected slot so that all
    # the object attributes (position and size) are available to the receiver.
    sendAperture = pyqtSignal('PyQt_PyObject')
    sendRecenter = pyqtSignal('PyQt_PyObject')
    sendSetThresh = pyqtSignal('PyQt_PyObject')
    sendSetGreen = pyqtSignal('PyQt_PyObject')
    sendSetYellow = pyqtSignal('PyQt_PyObject')
    sendDelete = pyqtSignal('PyQt_PyObject')
    sendThumbnailSource = pyqtSignal('PyQt_PyObject')
    sendSetRaDec = pyqtSignal('PyQt_PyObject')
    sendSetEarlyTrackPathPoint = pyqtSignal('PyQt_PyObject')
    sendSetLateTrackPathPoint = pyqtSignal('PyQt_PyObject')
    sendHotPixelRecord = pyqtSignal('PyQt_PyObject')
    sendClearTrackPath = pyqtSignal('PyQt_PyObject')

    def __init__(self, name, bbox, max_xpos, max_ypos):  # Intialize aperture specified by a bounding box
        self.name = name
        self.thresh = 0
        self.pen = pg.mkPen('r')
        self.color = 'red'
        self.x0, self.y0, self.xsize, self.ysize = bbox

        self.jogging_enabled = False
        self.auto_display = False
        self.thumbnail_source = False

        self.default_mask_radius = 3.0
        self.order_number = 0
        self.defaultMask = None
        self.defaultMaskPixelCount = None

        self.theta = None   # Holds angle to yellow #1 (if present)
        self.dx = None      # Holds x distance from yellow #1
        self.dy = None      # Holds y distance from yellow #1

        self.xc = None      # Will hold current x value of centroid in image coordinates
        self.yc = None      # Will hold current y value of centroid in image coordinates

        self.data = []

        # When created, we accept the callers restriction on the placement
        # of a bbox (bounding box) corner and enforce
        self.max_xpos = max_xpos
        self.max_ypos = max_ypos

        # Enforce the restrictions even during creation
        self.enforcePositioningConstraints(bbox)

        # menu creation is deferred because it is expensive and often
        # the user will never see the menu anyway.
        self.menu = None

        # note that the use of super() is often avoided because Qt does not
        # allow to inherit from multiple QObject subclasses.
        pg.GraphicsObject.__init__(self)

    def getBbox(self):
        return self.x0, self.y0, self.xsize, self.ysize

    def getCenter(self):
        return self.x0 + int(self.xsize / 2), self.y0 + int(self.ysize / 2)

    def setCenter(self, xc, yc):
        delta = int(self.xsize / 2)
        bbox = (xc - delta, yc - delta, self.xsize, self.ysize)
        self.enforcePositioningConstraints(bbox)

    def addData(self, data_tuple):
        self.data.append(data_tuple)

    def enforcePositioningConstraints(self, bbox):
        self.x0, self.y0, self.xsize, self.ysize = bbox

        # Enforce placement constraints
        if self.x0 < 0:
            self.x0 = 0
        if self.x0 > self.max_xpos:
            self.x0 = self.max_xpos

        if self.y0 < 0:
            self.y0 = 0
        if self.y0 > self.max_ypos:
            self.y0 = self.max_ypos

    def setPos(self, bbox):
        self.enforcePositioningConstraints(bbox)

    # All graphics items must have boundingRect() defined.
    def boundingRect(self):
        return QtCore.QRectF(self.x0, self.y0, self.xsize, self.ysize)

    # All graphics items must have paint() defined.
    def paint(self, p, *args):
        _ = args  # Just to satisfy PyCharm code inspector (need to use args in some manner)
        p.setPen(self.pen)
        p.drawRect(self.boundingRect())
        p.setPen(pg.mkPen('y'))
        p.drawLine(self.x0, self.y0, self.x0 + self.xsize, self.y0 + self.ysize)
        p.drawLine(self.x0, self.y0 + self.ysize, self.x0 + self.xsize, self.y0)

    # On right-click, raise the context menu
    def mouseClickEvent(self, ev):
        if ev.button() == QtCore.Qt.RightButton:
            if self.raiseContextMenu(ev):
                ev.accept()

    def raiseContextMenu(self, ev):
        menu = self.getContextMenus()

        # Let the scene add on to the end of our context menu
        # (this is optional)
        # menu = self.scene().addParentContextMenus(self, menu, ev)

        pos = ev.screenPos()
        menu.popup(QtCore.QPoint(pos.x(), pos.y()))
        return True

    # This method will be called when this item's _children_ want to raise
    # a context menu that possibly includes their parents' menus.
    def getContextMenus(self, event=None):
        if self.menu is None:
            self.menu = QtGui.QMenu()
            self.menu.setTitle(self.name + " options..")  # This appears to do nothing

            setthresh = QtGui.QAction("Set thresh", self.menu)
            setthresh.triggered.connect(self.setThresh)
            self.menu.addAction(setthresh)

            self.menu.addSeparator()

            delete = QtGui.QAction("Delete", self.menu)
            delete.triggered.connect(self.delete)
            self.menu.addAction(delete)

            rename = QtGui.QAction("Rename", self.menu)
            rename.triggered.connect(self.rename)
            self.menu.addAction(rename)

            self.menu.addSeparator()

            enable_jog = QtGui.QAction("Enable jogging via arrow keys", self.menu)
            enable_jog.triggered.connect(self.enableJog)
            self.menu.addAction(enable_jog)

            disable_jog = QtGui.QAction("Disable jogging", self.menu)
            disable_jog.triggered.connect(self.disableJog)
            self.menu.addAction(disable_jog)

            self.menu.addSeparator()

            enable_auto_display = QtGui.QAction("Enable auto display", self.menu)
            enable_auto_display.triggered.connect(self.enableAutoDisplay)
            self.menu.addAction(enable_auto_display)

            disable_auto_display = QtGui.QAction("Disable auto display", self.menu)
            disable_auto_display.triggered.connect(self.disableAutoDisplay)
            self.menu.addAction(disable_auto_display)

            self.menu.addSeparator()

            enable_thumbnail_source = QtGui.QAction("Set as Thumbnail source", self.menu)
            enable_thumbnail_source.triggered.connect(self.enableThumbnailSource)
            self.menu.addAction(enable_thumbnail_source)

            disable_thumbnail_source = QtGui.QAction("Unset as Thumbnail source", self.menu)
            disable_thumbnail_source.triggered.connect(self.disableThumbnailSource)
            self.menu.addAction(disable_thumbnail_source)

            self.menu.addSeparator()

            green = QtGui.QAction("Turn green (connect to threshold spinner)", self.menu)
            green.triggered.connect(self.setGreenRequest)
            self.menu.addAction(green)

            red = QtGui.QAction("Turn red", self.menu)
            red.triggered.connect(self.setRed)
            self.menu.addAction(red)

            yellow = QtGui.QAction("Turn yellow (use as tracking aperture)", self.menu)
            yellow.triggered.connect(self.setYellow)
            self.menu.addAction(yellow)

            white = QtGui.QAction("Turn white (special 'flash-tag' aperture)", self.menu)
            white.triggered.connect(self.setWhite)
            self.menu.addAction(white)

            self.menu.addSeparator()

            early_track_path_point = QtGui.QAction("Use current position as early track path point", self.menu)
            early_track_path_point.triggered.connect(self.setEarlyTrackPathPoint)
            self.menu.addAction(early_track_path_point)

            late_track_path_point = QtGui.QAction("Use current position as late track path point", self.menu)
            late_track_path_point.triggered.connect(self.setLateTrackPathPoint)
            self.menu.addAction(late_track_path_point)

            clear_track_path = QtGui.QAction("Clear track path", self.menu)
            clear_track_path.triggered.connect(self.clearTrackPath)
            self.menu.addAction(clear_track_path)

            self.menu.addSeparator()

            ra_dec = QtGui.QAction("Set RA Dec (from VizieR query results)", self.menu)
            ra_dec.triggered.connect(self.setRaDec)
            self.menu.addAction(ra_dec)

            self.menu.addSeparator()

            hot_pixel = QtGui.QAction("Record as hot-pixel", self.menu)
            hot_pixel.triggered.connect(self.handleHotPixel)
            self.menu.addAction(hot_pixel)

        return self.menu

    # Define context menu callbacks

    def handleHotPixel(self):
        self.sendHotPixelRecord.emit(self)

    def setEarlyTrackPathPoint(self):
        self.sendSetEarlyTrackPathPoint.emit(self)

    def setLateTrackPathPoint(self):
        self.sendSetLateTrackPathPoint.emit(self)

    def clearTrackPath(self):
        self.sendClearTrackPath.emit(self)

    # We have to emit this as a message so that the main program can look
    # through the list of apertures all clear any other aperture that has thumbnail_source set
    def enableThumbnailSource(self):
        self.sendThumbnailSource.emit(self)

    def disableThumbnailSource(self):
        self.thumbnail_source = False

    def setRaDec(self):
        self.sendSetRaDec.emit(self)

    def enableJog(self):
        self.jogging_enabled = True

    def disableJog(self):
        self.jogging_enabled = False

    def enableAutoDisplay(self):
        self.auto_display = True

    def disableAutoDisplay(self):
        self.auto_display = False

    def delete(self):
        self.sendDelete.emit(self)

    def setGreen(self):
        self.pen = pg.mkPen('g')
        self.color = 'green'
        self.update()

    def setGreenRequest(self):
        self.sendSetGreen.emit(self)

    def setRed(self):
        self.pen = pg.mkPen('r')
        self.color = 'red'
        self.update()

    def setWhite(self):
        self.pen = pg.mkPen('w')
        self.color = 'white'
        self.update()

    def setYellowNoCheck(self):
        self.pen = pg.mkPen('y')
        self.color = 'yellow'
        self.update()

    def setYellow(self):
        self.sendSetYellow.emit(self)

    def setThresh(self):
        self.sendSetThresh.emit(self)

    def rename(self):
        appNamerThing = AppNameDialog()
        appNamerThing.apertureNameEdit.setText(self.name)
        appNamerThing.apertureNameEdit.setFocus()
        result = appNamerThing.exec_()

        if result == QDialog.Accepted:
            self.name = appNamerThing.apertureNameEdit.text().strip()



import numpy as np
import os
from astropy.time import Time
from datetime import datetime, timedelta


SER_HEADER_SIZE = 178

def sharpCapTimestamp(datetime64):

    usecs = int(datetime64 // 10)
    extra_digit = datetime64 - 10 * usecs
    ts = (datetime(1, 1, 1) + timedelta(microseconds=usecs))

    timestamp = (f'{ts.year}-{ts.month}-{ts.day}T{ts.hour:02d}:{ts.minute:02d}:{ts.second:02d}.{ts.microsecond:06d}'
                f'{extra_digit}')
    return timestamp

def convertNETdatetimeToJD(datetime64):
    jd = datetime64 / 864000000000 + 1721424.5
    return jd


def convertJDtoTimestamp(jd):
    t = Time(jd, format='jd', precision=4)
    return t.isot


def stringFromByteArray(byteArray):
    listOfCharacters = ""
    for byte in byteArray:
        listOfCharacters += chr(byte)
    return "".join(listOfCharacters)


def getMetaData(fpath):
    # Using the SER format description version 3 by Gischa Hahn 2014 Feb 06,
    # this function puts the meta-data into a dictionary and the timestamps (if any)
    # into a list and returns both.  All 'endian' requirements are followed EXCEPT
    # that the prevailing convention now is to treat a value of 0 in the LittleEndian
    # field is specifying little-endian byte order in 16 bit image data (opposite of 'spec').

    with open(fpath, 'rb') as f:

        ans = {}
        timestamps = []

        raw_file_ID = np.fromfile(f, dtype='uint8', count=14)
        FileID = stringFromByteArray(raw_file_ID)
        ans.update(FileID=FileID)

        # '<i4' specifies a little-endian 32 bit int
        LuID = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(LuID=LuID)

        ColorID = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(ColorID=ColorID)

        if not ColorID == 0:  # monochrome image
            raise ValueError("Color SER files not supported.  Only mono")

        LittleEndian = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(LittleEndian=LittleEndian)

        ImageWidth = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(ImageWidth=ImageWidth)

        ImageHeight = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(ImageHeight=ImageHeight)

        PixelDepthPerPlane = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(PixelDepthPerPlane=PixelDepthPerPlane)

        FrameCount = np.fromfile(f, dtype='<i4', count=1)[0]
        ans.update(FrameCount=FrameCount)

        raw_observer = np.fromfile(f, dtype='uint8', count=40)
        Observer = stringFromByteArray(raw_observer)
        ans.update(Observer=Observer)

        raw_instrument = np.fromfile(f, dtype='uint8', count=40)
        Instrument = stringFromByteArray(raw_instrument)
        ans.update(Instrument=Instrument)

        raw_telescope = np.fromfile(f, dtype='uint8', count=40)
        Telescope = stringFromByteArray(raw_telescope)
        ans.update(Telescope=Telescope)

        # '<i8' specifies a little-endian 64 bit integer
        datetimeLocal = np.fromfile(f, dtype='<i8', count=1)[0]
        # DateTimeLocal = convertJDtoTimestamp(convertNETdatetimeToJD(datetimeLocal))
        DateTimeLocal = sharpCapTimestamp(datetimeLocal)
        ans.update(DateTimeLocal=DateTimeLocal)

        datetimeUTC = np.fromfile(f, dtype='<i8', count=1)[0]
        # DateTimeUTC = convertJDtoTimestamp(convertNETdatetimeToJD(datetimeUTC))
        DateTimeUTC = sharpCapTimestamp(datetimeUTC)

        ans.update(DateTimeUTC=DateTimeUTC)

        if PixelDepthPerPlane > 8:
            BytesPerPixel = 2
        else:
            BytesPerPixel = 1
        ans.update(BytesPerPixel=BytesPerPixel)

        ImageDataSize = int(FrameCount) * int(ImageWidth) * int(ImageHeight) * int(BytesPerPixel)
        ans.update(ImageDataSize=ImageDataSize)

        # Two ways to get file size
        # f.seek(0,2)           # set position to offset=0 from end of file
        # fileSize = f.tell()   # tell what that position is
        FileSize = os.path.getsize(fpath)
        ans.update(FileSize=FileSize)

        NumTimestamps = (FileSize - SER_HEADER_SIZE - ImageDataSize) / 8
        ans.update(NumTimestamps=NumTimestamps)

        PositionOfTimestamps = ImageDataSize + SER_HEADER_SIZE
        ans.update(PositionOfTimestamps=PositionOfTimestamps)

        if NumTimestamps > 0:
            f.seek(PositionOfTimestamps)
            for i in range(int(NumTimestamps)):
                datetimeUTC = np.fromfile(f, dtype='<i8', count=1)[0]
                DateTimeUTC = sharpCapTimestamp(datetimeUTC)
                # DateTimeUTC = convertJDtoTimestamp(convertNETdatetimeToJD(datetimeUTC))
                timestamps.append(DateTimeUTC)

    return ans, timestamps

def getSerImage(f, frameNum, bytes_per_pixel, image_width, image_height, little_endian):
    # height is y axis   width is x axis
    num_pixels_in_frame = image_height * image_width
    frame_size = bytes_per_pixel * num_pixels_in_frame
    frame_start = int(frame_size) * int(frameNum) + SER_HEADER_SIZE
    f.seek(frame_start)
    if bytes_per_pixel == 1:
        img = np.fromfile(f, dtype='uint8', count=num_pixels_in_frame)
    elif bytes_per_pixel == 2:
        if little_endian == 0:
            img = np.fromfile(f, dtype='<u2', count=num_pixels_in_frame)
        else:
            img = np.fromfile(f, dtype='>u2', count=num_pixels_in_frame)
    else:
        raise ValueError("bytes_per_pixel must be 1 or 2")
    return img.reshape(image_height, image_width)

#   test_file = r'/Users/bob/Dropbox/SER project/ser-files-from-jan/FireCapture/190822_212734.ser'
#   meta_data, timestamps = getMetaData(test_file)
#
#   f = open(test_file, 'rb') # Leave file handle open to speed repeat reads from file
#   image = getSerImage(f, 43, meta_data['BytesPerPixel'], meta_data['ImageWidth'], meta_data['ImageHeight'], meta_data['LittleEndian'])
#   f.close() # Remember to close the file handle when no more images need to read from the file